==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "J'ai lu et j'accepte le contrat de licence."

, "License Agreement"
: "Contrat de licence"

, "I have read the privacy agreement and accept it"
: "J'ai lu et j'accepte la politique de confidentialité"

, "Privacy Agreement"
: "Politique de confidentialité"

, "Accept Terms and Conditions"
: "Accepter les conditions générales"

, "Backend"
: "Système en arrière-plan"

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Nom d'hôte"

, "Username"
: "Nom d'utilisateur"

, "Password"
: "Mot de passe"

, "Port"
: "Port"

, "Secure Connection"
: "Connexion sécurisée"

, "None"
: "Aucun"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Utiliser un compte système"

, "No"
: "Non"

, "Yes"
: "Oui"

, "Append domain to login name"
: "Ajouter le domaine au nom de connexion"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrateur Cyrus"

, "Cyrus Admin Password"
: "Mot de passe de l'adminstrateur Cyrus"

, "Use proxy auth"
: "Utiliser un proxy d'identification"

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentification"

, "Login"
: "Login"

, "Plain"
: "Plein"

, "Primary Domain"
: "Domaine principal"

, "Secondary Domains (comma separated)"
: "Domaines secondaires (séparés par une virgule)"

, "Notifications service address"
: "Adresse du service de notification"

, "Notification Username"
: "Nom des notifications"

, "Notification Password"
: "Mot de passe des notifications"

, "Notifications local client (hostname or IP address)"
: "Notifications du client local (nom d'hôte ou adresse IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Nom d'hôte MySql"

, "MySql Database"
: "Base MySql"

, "MySql User"
: "Utilisateur MySql"

, "MySql Password"
: "Mot de passe MySql"

, "MySql Port"
: "Port MySql"

, "User or UID"
: "Utilisateur ou UID"

, "Group or GID"
: "Groupe ou GID"

, "Home Template"
: "Modèle des Home"

, "Password Scheme"
: "Schéma des mots de passe"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Conditions générales"

, "Setup Checks"
: "Vérifications de l'installation"

, "Config Manager"
: "Gestionnaire de configuration"

, "Authentication/Accounts"
: "Authentification/Comptes"

, "Email"
: "Email"

, "Application Manager"
: "Gestionnaire d'application"

, "Setup"
: ""

, "Name"
: "Nom"

, "Enabled"
: "Activé"

, "Order"
: "Ordre"

, "Installed Version"
: "Version installée"

, "Available Version"
: "Version disponible"

, "Status"
: "Statut"

, "Depends on"
: "Dépend de"

, "Install application"
: "Installer"

, "Uninstall application"
: "désinstaller"

, "Update application"
: "Mettre à jour"

, "Go to {0} login"
: "Aller à la page de login de {0}"

, "uninstall"
: "désinstaller"

, "Do you really want to uninstall the application(s)?"
: "Êtes-vous sûr de vouloir désinstaller l'application?"

, "This may take a while"
: "Cela peut être long"

, "Dependency Violation"
: "Violation de dépendances"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Supprimer tous les groupes et utilisateurs existants"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Basculer du SQL en LDAP supprimera tous les comptes, groupes et rôles. Êtes-vous sûrs de vouloir basculer en authentification LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Administrateur initial"

, "Initial admin login name"
: "Login administrateur initial"

, "Initial admin Password"
: "Mot de passe administrateur initial"

, "Password confirmation"
: "Confirmation du mot de passe"

, "Authentication provider"
: "Fournisseur d'authentification"

, "Try to split username"
: "Essayez de séparer le nom d'utilisateur"

, "Account canonical form"
: "Forme canonique du compte"

, "Account domain name"
: ""

, "Account domain short name"
: "Nom court de domaine du compte"

, "Host"
: "Nom d'hôte"

, "Login name"
: "Login"

, "Bind requires DN"
: "La connexion nécessite un DN"

, "Start TLS"
: "StartTLS"

, "Base DN"
: "Base DN"

, "Search filter"
: "Filtre de recherche"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Stockage des comptes"

, "Default user group name"
: "Nom du groupe utilisateur par défaut"

, "Default admin group name"
: "Nom du groupe administrateur par défaut"

, "Login panel"
: "Panneau de connexion"

, "Reuse last username logged"
: "Afficher le nom du dernier compte utilisé"

, "Password Settings"
: "Paramétrage des mots de passe"

, "User can change password"
: "L'utilisateur peut changer de mot de passe"

, "Enable password policy"
: "Activer le paramétrage des mots de passe"

, "Only ASCII"
: "Seulement ASCII"

, "Minimum length"
: "Longueur minimum"

, "Minimum word chars"
: "Nombre minimum de lettres"

, "Minimum uppercase chars"
: "Nombre minimum de lettres en majuscule"

, "Minimum special chars"
: "Nombre minimum de caractères spéciaux"

, "Minimum numbers"
: "Nombre minimum de chiffres"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Interdire l'utilisation de tout ou partie du nom d'utilisateur dans le mot de passe"

, "Redirect Settings"
: "Paramètres de redirection"

, "Redirect Url (redirect to login screen if empty)"
: "URL de redirection (si laissé vide, redirigera vers la page de connexion)"

, "Redirect Always (if No, only redirect after logout)"
: "Toujours rediriger (si Non, ne rediriger qu'après la déconnexion)"

, "Redirect to referring site, if exists"
: "Redirection vers le site de référence, s'il existe"

, "Password encoding"
: "Encodage du mot de passe"

, "des"
: "DES"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "clair"

, "User DN"
: "User DN"

, "User Filter"
: "Filtre des utilisateurs"

, "User Search Scope"
: "Champs de recherche des utilisateurs"

, "Groups DN"
: "Groups DN"

, "Group Filter"
: "Filtre des groupes"

, "Group Search Scope"
: "Champs de recherche des groupes"

, "Use Rfc 2307 bis"
: "Utiliser la  Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Maintenir les attributs RFC 2307"

, "Min User Id"
: "UUID minimum"

, "Max User Id"
: "UUID maximun"

, "Min Group Id"
: "GUID minimum"

, "Max Group Id"
: "GUID maximun"

, "Group UUID Attribute name"
: "Nom d'attribut de groupe (GUID)"

, "User UUID Attribute name"
: "Nome d'attribut utilisateur (UUID)"

, "Readonly access"
: "Accès en lecture seule"

, "Save config and install"
: "Enregistrer la configuration et installer"

, "Save config"
: "Enregistrer la configuration"

, "Passwords don't match"
: "Les mots de passes ne correspondent pas!"

, "Should not be empty"
: "Ne devrait pas être vide"

, "Performing Environment Checks..."
: "Vérification en cours..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Impossible de trouver {0}. Veuillez modifier votre filtre, votre mode d'affichage ou le {1} dans lequel vous cherchez"

, "Check"
: "Vérification"

, "Result"
: "Résultat"

, "Error"
: "Erreur"

, "Run setup tests"
: "Lancer les tests d'installation"

, "Ignore setup tests"
: "ignorer les tests d'installation"

, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "File"
: "Fichier"

, "Setup Authentication"
: "Configuration de l'authentification"

, "Database"
: "Base de données"

, "User"
: "Utilisateur"

, "Prefix"
: "Préfixe"

, "Logging"
: "Journalisation"

, "Filename"
: "Nom du fichier"

, "Priority"
: "Priorité"

, "Caching"
: "Mise en cache"

, "Lifetime (seconds)"
: "Durée de vie (secondes)"

, "Path"
: "Chemin"

, "Queue"
: "File"

, "Session"
: "Session"

, "Temporary files"
: "Fichiers temporaires"

, "Temporary Files Path"
: "Emplacement des fichiers temporaires"

, "Filestore directory"
: "Répertoire de stockage des fichiers"

, "Filestore Path"
: "Chemin du stockage des fichiers"

, "Addressbook Map panel"
: "Carte du carnet d'adresse"

, "Map panel"
: "Carte"

, "disabled"
: "désactivé"

, "enabled"
: "activé"

, "Config file is not writable"
: "Le ifchier de configuration n'est pas modifiable"

, "Download config file"
: "Télécharger la configuration"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Application"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Vérification en cours..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Impossible de trouver {0}. Veuillez modifier votre filtre, votre mode d'affichage ou le {1} dans lequel vous cherchez"

, "Check"
: "Vérification"

, "Result"
: "Résultat"

, "Message"
: ""

, "Run setup tests"
: "Lancer les tests d'installation"

, "Ignore setup tests"
: "ignorer les tests d'installation"

, "Install application"
: "Installer"

, "Name"
: "Nom"

, "Enabled"
: "Activé"

, "Order"
: "Ordre"

, "Installed Version"
: "Version installée"

, "Available Version"
: "Version disponible"

, "Status"
: "Statut"

, "Depends on"
: "Dépend de"

, "Uninstall application"
: "désinstaller"

, "Update applications"
: ""

, "Go to {0} login"
: "Aller à la page de login de {0}"

, "uninstall"
: "désinstaller"

, "Do you really want to uninstall the application(s)?"
: "Êtes-vous sûr de vouloir désinstaller l'application?"

, "This may take a while"
: "Cela peut être long"

, "Dependency Violation"
: "Violation de dépendances"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Supprimer tous les groupes et utilisateurs existants"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Basculer du SQL en LDAP supprimera tous les comptes, groupes et rôles. Êtes-vous sûrs de vouloir basculer en authentification LDAP?"

, "Backend"
: "Système en arrière-plan"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Administrateur initial"

, "Initial admin login name"
: "Login administrateur initial"

, "Initial admin Password"
: "Mot de passe administrateur initial"

, "Password confirmation"
: "Confirmation du mot de passe"

, "Authentication provider"
: "Fournisseur d'authentification"

, "Try to split username"
: "Essayez de séparer le nom d'utilisateur"

, "Yes"
: "Oui"

, "No"
: "Non"

, "Account canonical form"
: "Forme canonique du compte"

, "Account domain name"
: ""

, "Account domain short name"
: "Nom court de domaine du compte"

, "Host"
: "Nom d'hôte"

, "Login name"
: "Login"

, "Password"
: "Mot de passe"

, "Bind requires DN"
: "La connexion nécessite un DN"

, "Start TLS"
: "StartTLS"

, "SSL"
: "SSL"

, "Port"
: "Port"

, "Base DN"
: "Base DN"

, "Search filter"
: "Filtre de recherche"

, "Hostname"
: "Nom d'hôte"

, "Secure Connection"
: "Connexion sécurisée"

, "None"
: "Aucun"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Ajouter le domaine au nom de connexion"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Stockage des comptes"

, "Default user group name"
: "Nom du groupe utilisateur par défaut"

, "Default admin group name"
: "Nom du groupe administrateur par défaut"

, "Login panel"
: "Panneau de connexion"

, "Reuse last username logged"
: "Afficher le nom du dernier compte utilisé"

, "Password Settings"
: "Paramétrage des mots de passe"

, "User can change password"
: "L'utilisateur peut changer de mot de passe"

, "Enable password policy"
: "Activer le paramétrage des mots de passe"

, "Only ASCII"
: "Seulement ASCII"

, "Minimum length"
: "Longueur minimum"

, "Minimum word chars"
: "Nombre minimum de lettres"

, "Minimum uppercase chars"
: "Nombre minimum de lettres en majuscule"

, "Minimum special chars"
: "Nombre minimum de caractères spéciaux"

, "Minimum numbers"
: "Nombre minimum de chiffres"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Interdire l'utilisation de tout ou partie du nom d'utilisateur dans le mot de passe"

, "Redirect Settings"
: "Paramètres de redirection"

, "Redirect Url (redirect to login screen if empty)"
: "URL de redirection (si laissé vide, redirigera vers la page de connexion)"

, "Redirect Always (if No, only redirect after logout)"
: "Toujours rediriger (si Non, ne rediriger qu'après la déconnexion)"

, "Redirect to referring site, if exists"
: "Redirection vers le site de référence, s'il existe"

, "Password encoding"
: "Encodage du mot de passe"

, "des"
: "DES"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "clair"

, "User DN"
: "User DN"

, "User Filter"
: "Filtre des utilisateurs"

, "User Search Scope"
: "Champs de recherche des utilisateurs"

, "Groups DN"
: "Groups DN"

, "Group Filter"
: "Filtre des groupes"

, "Group Search Scope"
: "Champs de recherche des groupes"

, "Use Rfc 2307 bis"
: "Utiliser la  Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Maintenir les attributs RFC 2307"

, "Min User Id"
: "UUID minimum"

, "Max User Id"
: "UUID maximun"

, "Min Group Id"
: "GUID minimum"

, "Max Group Id"
: "GUID maximun"

, "Group UUID Attribute name"
: "Nom d'attribut de groupe (GUID)"

, "User UUID Attribute name"
: "Nome d'attribut utilisateur (UUID)"

, "Readonly access"
: "Accès en lecture seule"

, "Save config and install"
: "Enregistrer la configuration et installer"

, "Save config"
: "Enregistrer la configuration"

, "Passwords don't match"
: "Les mots de passes ne correspondent pas!"

, "Should not be empty"
: "Ne devrait pas être vide"

, "File"
: "Fichier"

, "Setup Authentication"
: "Configuration de l'authentification"

, "Username"
: "Nom d'utilisateur"

, "Database"
: "Base de données"

, "User"
: "Utilisateur"

, "Prefix"
: "Préfixe"

, "Logging"
: "Journalisation"

, "Filename"
: "Nom du fichier"

, "Priority"
: "Priorité"

, "Caching"
: "Mise en cache"

, "Lifetime (seconds)"
: "Durée de vie (secondes)"

, "Path"
: "Chemin"

, "Queue"
: "File"

, "Session"
: "Session"

, "Temporary files"
: "Fichiers temporaires"

, "Temporary Files Path"
: "Emplacement des fichiers temporaires"

, "Filestore directory"
: "Répertoire de stockage des fichiers"

, "Filestore Path"
: "Chemin du stockage des fichiers"

, "Addressbook Map panel"
: "Carte du carnet d'adresse"

, "Map panel"
: "Carte"

, "disabled"
: "désactivé"

, "enabled"
: "activé"

, "Config file is not writable"
: "Le ifchier de configuration n'est pas modifiable"

, "Download config file"
: "Télécharger la configuration"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Utiliser un compte système"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrateur Cyrus"

, "Cyrus Admin Password"
: "Mot de passe de l'adminstrateur Cyrus"

, "Use proxy auth"
: "Utiliser un proxy d'identification"

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentification"

, "Login"
: "Login"

, "Plain"
: "Plein"

, "Primary Domain"
: "Domaine principal"

, "Secondary Domains (comma separated)"
: "Domaines secondaires (séparés par une virgule)"

, "Notifications service address"
: "Adresse du service de notification"

, "Notification Username"
: "Nom des notifications"

, "Notification Password"
: "Mot de passe des notifications"

, "Notifications local client (hostname or IP address)"
: "Notifications du client local (nom d'hôte ou adresse IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Nom d'hôte MySql"

, "MySql Database"
: "Base MySql"

, "MySql User"
: "Utilisateur MySql"

, "MySql Password"
: "Mot de passe MySql"

, "MySql Port"
: "Port MySql"

, "User or UID"
: "Utilisateur ou UID"

, "Group or GID"
: "Groupe ou GID"

, "Home Template"
: "Modèle des Home"

, "Password Scheme"
: "Schéma des mots de passe"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Setup"
: ""

, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "Terms and Conditions"
: "Conditions générales"

, "Setup Checks"
: "Vérifications de l'installation"

, "Config Manager"
: "Gestionnaire de configuration"

, "Authentication/Accounts"
: "Authentification/Comptes"

, "Email"
: "Email"

, "Application Manager"
: "Gestionnaire d'application"

, "I have read the license agreement and accept it"
: "J'ai lu et j'accepte le contrat de licence."

, "License Agreement"
: "Contrat de licence"

, "I have read the privacy agreement and accept it"
: "J'ai lu et j'accepte la politique de confidentialité"

, "Privacy Agreement"
: "Politique de confidentialité"

, "Accept Terms and Conditions"
: "Accepter les conditions générales"


, "Application"
: "Application"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
